# mercurial configuration file for bundled hg extensions
# See hgrc(5) for more information

# Extensions included in Mercurial listed in alphabetical order
[extensions]

# changeset access control
# hgext.acl =

# allow user-defined command aliases
# hgext.alias =

# provides the 'bookmarks' command
# hgext.bookmarks =

# bugzilla integration
# requires python3-mysqldb
# hgext.bugzilla =

# show the children of the given or working dir revision
# provides the 'children' command
# hgext.children =

# graph count of revisions grouped by template
# provides the 'churn' command
# hgext.churn =

# add color output to status, qseries, and diff-related commands
# hgext.color =

# converts a foreign SCM to a Mercurial one
# provides the 'convert' and 'debugsvnlog' commands
# requires:
# - bzr to convert from Bazaar
# - cvs to convert from CVS
# - darcs to convert from Darcs
# - git to convert from Git
# - tla to convert from GNU Arch
# - monotone to convert from Monotone
# - python3-subversion to convert from Subversion
# hgext.convert =

# external diff program support
# hgext.extdiff =

# pull and merge remote changes
# provides the 'fetch' command
# hgext.fetch =

# GnuPG signing
# provides the 'sign', 'sigcheck' and 'sigs' commands
# requires gnupg
# hgext.gpg =

# show revision graphs in terminal windows
# provides the 'glog' command
# hgext.graphlog =

# CIA notification hook
# hgext.hgcia =

# allows browsing the history of a repository in a graphical way
# provides the 'view' command
# requires wish
# hgext.hgk =

# syntax highlighting in hgweb
# requires python3-pygments
# hgext.highlight =

# lets you split a merge into pieces
# provides the 'imerge' command
# hgext.imerge =

# inotify-based status acceleration for Linux systems
# provides the 'inserve' command
# hgext.inotify =

# allows you to change changelog and summary text
# hgext.interhg =

# CVS/RCS-like keyword expansion
# hgext.keyword =

# quilt-like patch queues
# provides the 'q*' commands
# hgext.mq =

# email notifications
# hgext.notify =

# display output using a pager
# hgext.pager =

# make it easy to refer to the parent of a revision
# hgext.parentrevspec =

# send changes as series of email patches
# provides the 'email' command
# hgext.patchbomb =

# removes files not known to mercurial
# provides the 'purge' command
# hgext.purge =

# moves sets of revisions to a different ancestor
# provides the 'rebase' command
# hgext.rebase =

# interactive change selection during commit
# provides the 'record' command
# hgext.record =

# patch transplanting tool
# provides the 'transplant' command
# hgext.transplant =

# non-Unicode MBCS filename support
# hgext.win32mbcs =

# Unix/Mac/DOS line ending conversion utilities
# hgext.win32text =

# mDNS/DNS-SD (Zeroconf) support for 'hg serve'
# hgext.zeroconf =
